@@ -9,6 +9,11 @@ import argparse
 import json
 import traceback
 
+mysqlcmds = dict()
+mysqlcmds["show databases"] = "select * from information_schema.schemata"
+mysqlcmds["show tables"] = "select table_schema, table_name, table_type type, engine, table_rows, avg_row_length, data_length, coalesce(update_time,create_time) last_change, check_time last_chk from information_schema.tables where database() is NULL or table_schema = database()"
+
+
 
 def mysqlx_main():
     parser = argparse.ArgumentParser(description="yet another mysql client CLI tool/shell")
@@ -111,22 +116,38 @@ def mysqlx_main():
     )
     args = parser.parse_args()
 
-    if args.nowrap:
-        args.plain = True
     if args.plain:
         os.environ["force_ansicolor"] = "0"
 
-    def xtimeout_call(fn=None, msg="timeouted.") :
+    def xtimeout_call(fn=None, msg="timeouted.",exitfn=None) :
         import signal
         TIMEOUT = 1
         def interrupted(signal, frame):
             print("# {}".format(msg), file=sys.stderr, flush=True)
-            return 0
+            if exitfn :
+                exitfn()
+            sys.exit(-1)
         signal.signal(signal.SIGALRM, interrupted)
         signal.alarm(TIMEOUT)
-        res = fn()
+        res = None
+        if fn :
+            res = fn()
         signal.alarm(0)
         return res
+    xinput = xtimeout_call(sys.stdin.read, "Timeout getting input from STDIN.", parser.print_help)
+    xinput = xinput.strip()
+    if not (xinput.lower().startswith("select") \
+      or xinput.lower().startswith("update") \
+      or xinput.lower().startswith("insert") \
+      or xinput.lower().startswith("delete") \
+      or xinput.lower().startswith("with") ) :
+          k = re.sub(r"\s+"," ",xinput.lower())
+          if k in mysqlcmds :
+              xinput = mysqlcmds[k]
+          else :
+              xinput = None
+    print(xinput)
+
 
 
 if __name__ == "__main__":
